import {
  isNotNull
} from "./chunk-V5ZQ2SFQ.js";

// src/node/log/log-util.ts
import { resolve } from "node:path";
import process from "node:process";
function getStackLlocationList(stack) {
  if (typeof stack !== "string")
    return [];
  return stack?.split("\n").map((rawLine) => {
    const m = rawLine.match(
      // eslint-disable-next-line regexp/no-super-linear-backtracking
      /^\s+at.*(\((.*)\)|file:\/\/(.*)$)|\s*at\s(\/.*)$/
    );
    if (m) {
      let line = m[3] || m[2] || m[4];
      if (line.endsWith(")"))
        line = line.slice(0, -1);
      return line;
    }
    return void 0;
  })?.filter(isNotNull) ?? [];
}
function pathStripCwd(path) {
  if (path.includes("/node_modules/"))
    return "";
  const fileURL = "file://";
  if (path.startsWith(fileURL))
    return path.substr(fileURL.length);
  const cwd = resolve(process.cwd());
  if (cwd && path.startsWith(cwd))
    return path.substr(cwd.length + 1);
  const home = process.env?.HOME ? resolve(process.env?.HOME) : "";
  if (home && path.startsWith(home))
    path = `~/${path.substr(home.length + 1)}`;
  return path;
}
function extractFileInfo(stackLine) {
  const m = stackLine.match(/^\s*at.*(\((.*)\)|file:\/\/(.*)$)|\s*at\s(\/.*)$/);
  if (m) {
    let line = m[3] || m[2] || m[4];
    if (line.endsWith(")"))
      line = line.slice(0, -1);
    return line;
  }
  return "";
}
function getSourceLocation(level = 2, stripCwd = true) {
  const stack = new Error("stack").stack || "";
  let line = getStackLlocationList(stack)?.[level];
  if (line && stripCwd)
    line = pathStripCwd(line);
  return line || "";
}
function getStack() {
  return new Error("stack").stack || "";
}
function getSourceLocationByPrecedingPattern(patterns, stripCwd = true) {
  let line = "";
  const stack = new Error("stack").stack || "";
  if (typeof stack === "string") {
    const lines = stack.split("\n").map((l) => l.trim());
    const index = lines.findIndex((l) => patterns.some((p) => l.startsWith(p)));
    line = lines[index + 1];
    if (line)
      line = extractFileInfo(line);
    if (line && stripCwd)
      line = pathStripCwd(line);
  }
  return line;
}

export {
  getStackLlocationList,
  getSourceLocation,
  getStack,
  getSourceLocationByPrecedingPattern
};
//# sourceMappingURL=chunk-HMSGRZZF.js.map