"use strict";Object.defineProperty(exports, "__esModule", {value: true}); function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; } function _nullishCoalesce(lhs, rhsFn) { if (lhs != null) { return lhs; } else { return rhsFn(); } } function _optionalChain(ops) { let lastAccessLHS = undefined; let value = ops[0]; let i = 1; while (i < ops.length) { const op = ops[i]; const fn = ops[i + 1]; i += 2; if ((op === 'optionalAccess' || op === 'optionalCall') && value == null) { return undefined; } if (op === 'access' || op === 'optionalAccess') { lastAccessLHS = value; value = fn(value); } else if (op === 'call' || op === 'optionalCall') { value = fn((...args) => value.call(lastAccessLHS, ...args)); lastAccessLHS = undefined; } } return value; }// src/node/env.ts
var _fs = require('fs'); var _fs2 = _interopRequireDefault(_fs);
var _path = require('path');
var _process = require('process'); var _process2 = _interopRequireDefault(_process);
var NEWLINE = "\n";
var RE_INI_KEY_VAL = /^\s*([\w.-]+)\s*=\s*(.*)\s*$/;
var RE_NEWLINES = /\\n/g;
var NEWLINES_MATCH = /\r\n|\n|\r/;
function parse(src, _options = {}) {
  const obj = {};
  String(src).split(NEWLINES_MATCH).forEach((line, idx) => {
    const keyValueArr = line.match(RE_INI_KEY_VAL);
    if (keyValueArr != null) {
      const key = keyValueArr[1];
      let val = keyValueArr[2] || "";
      const end = val.length - 1;
      const isDoubleQuoted = val[0] === '"' && val[end] === '"';
      const isSingleQuoted = val[0] === "'" && val[end] === "'";
      if (isSingleQuoted || isDoubleQuoted) {
        val = val.substring(1, end);
        if (isDoubleQuoted)
          val = val.replace(RE_NEWLINES, NEWLINE);
      } else {
        val = val.trim();
      }
      obj[key] = val;
    }
  });
  return obj;
}
function stringToPath(value, defaultValue = ".") {
  return _path.resolve.call(void 0, _process2.default.cwd(), _nullishCoalesce(value, () => ( defaultValue)));
}
function valueToPath(value, defaultValue = "") {
  if (value == null)
    value = defaultValue;
  return stringToPath(String(value).trim(), defaultValue);
}
var toPath = valueToPath;
function getEnvVariableRelaxed(name, env = _process2.default.env) {
  if (env[name] != null)
    return env[name];
  name = name.toLowerCase();
  for (const [k, v] of Object.entries(env)) {
    if (k.toLowerCase() === name)
      return v;
  }
}
function setupEnv(options = {}) {
  const dotenvPath = _nullishCoalesce(_optionalChain([options, 'optionalAccess', _ => _.path]), () => ( toPath(_nullishCoalesce(_optionalChain([options, 'optionalAccess', _2 => _2.filename]), () => ( ".env")))));
  const encoding = _nullishCoalesce(_optionalChain([options, 'optionalAccess', _3 => _3.encoding]), () => ( "utf8"));
  const debug = _optionalChain([options, 'optionalAccess', _4 => _4.debug]) || false;
  try {
    let envOf2 = function(name) {
      return _fs2.default.existsSync(name) ? parse(_fs2.default.readFileSync(name, { encoding }), { debug }) : {};
    };
    var envOf = envOf2;
    const parsed = {};
    Object.assign(
      parsed,
      envOf2(dotenvPath),
      envOf2(`${dotenvPath}.local`)
    );
    if (options.mode) {
      Object.assign(
        parsed,
        envOf2(`${dotenvPath}.${options.mode}`),
        envOf2(`${dotenvPath}.${options.mode}.local`)
      );
    }
    const env = _nullishCoalesce(_optionalChain([options, 'optionalAccess', _5 => _5.env]), () => ( _process2.default.env));
    Object.entries(parsed).forEach(([key, value]) => {
      if (typeof _optionalChain([options, 'optionalAccess', _6 => _6.prefix]) === "string")
        key = _optionalChain([options, 'optionalAccess', _7 => _7.prefix]) + key;
      if (!Object.prototype.hasOwnProperty.call(env, key)) {
        if (value != null)
          env[key] = value;
      }
    });
    return { parsed };
  } catch (e) {
    return { error: e };
  }
}







exports.stringToPath = stringToPath; exports.valueToPath = valueToPath; exports.toPath = toPath; exports.getEnvVariableRelaxed = getEnvVariableRelaxed; exports.setupEnv = setupEnv;
//# sourceMappingURL=chunk-KM2MJVXI.cjs.map