// src/common/exec/promise.ts
function createPromise() {
  let resolve, reject;
  const promise = new Promise((_resolve, _reject) => {
    resolve = _resolve;
    reject = _reject;
  });
  return [promise, resolve, reject];
}
async function sleep(milliSeconds) {
  return new Promise((resolve) => setTimeout(resolve, milliSeconds));
}
async function immediate() {
  return new Promise((resolve) => setTimeout(resolve, 0));
}
async function timeout(promise, milliSeconds, timeoutValue = "timeoutReached") {
  return new Promise((resolve, reject) => {
    let done = false;
    const timeout2 = setTimeout(() => {
      done = true;
      resolve(timeoutValue);
    }, milliSeconds);
    promise.then((result) => {
      clearTimeout(timeout2);
      if (!done)
        resolve(result);
    }).catch((err) => {
      clearTimeout(timeout2);
      if (!done)
        reject(err);
    });
  });
}
function isTimeout(value) {
  return value === "timeoutReached" || value?.name === "Timeout reached";
}
async function tryTimeout(promise, milliSeconds) {
  if (milliSeconds <= 0)
    return await promise;
  return new Promise((resolve, reject) => {
    let done = false;
    const timeout2 = setTimeout(() => {
      done = true;
      reject(new Error("Timeout reached"));
    }, milliSeconds);
    promise.then((result) => {
      clearTimeout(timeout2);
      if (!done)
        resolve(result);
    }).catch((err) => {
      clearTimeout(timeout2);
      if (!done)
        reject(err);
    });
  });
}
function waitOn(obj, event, timeoutMS = 1e3) {
  return new Promise((resolve, reject) => {
    const fn = (value) => {
      if (timer) {
        clearTimeout(timer);
        done();
        resolve(value);
      }
    };
    let done = () => {
      timer = null;
      if (obj.off)
        obj.off(event, fn);
      else if (obj.removeEventListener)
        obj.removeEventListener(event, fn);
    };
    let timer = setTimeout(() => {
      done();
      reject(new Error("Did not response in time"));
    }, timeoutMS);
    if (obj.on)
      obj.on(event, fn);
    else if (obj.addEventListener)
      obj.addEventListener(event, fn);
  });
}
function isPromise(value) {
  return Boolean(value && (value instanceof Promise || typeof value.then === "function"));
}
function promisify(value) {
  return Promise.resolve(value);
}

export {
  createPromise,
  sleep,
  immediate,
  timeout,
  isTimeout,
  tryTimeout,
  waitOn,
  isPromise,
  promisify
};
//# sourceMappingURL=chunk-L324TYGN.js.map