import "../../chunk-UVCEAJ4D.js";
import "../../chunk-UMUHNSGZ.js";
import "../../chunk-XBO3LADP.js";
import {
  bitfield,
  createBinaryStreamDecoder,
  createBinaryStreamEncoder,
  encodeJson
} from "../../chunk-JY67VEDO.js";
import "../../chunk-DVBRAJ3X.js";
import "../../chunk-UXCQ43AH.js";
import "../../chunk-GKKLBSFA.js";
import "../../chunk-RNL46FQ3.js";
import "../../chunk-MWUFUBY5.js";
import "../../chunk-FLFB2K34.js";
import "../../chunk-264HKVNG.js";
import "../../chunk-H2GCNFWS.js";
import "../../chunk-AJCIHTGI.js";
import "../../chunk-HST4VI64.js";
import "../../chunk-A7SUGWC3.js";
import "../../chunk-M6NJWFDP.js";
import "../../chunk-6B24OWYC.js";
import "../../chunk-KDP637GO.js";
import "../../chunk-A4L4FO52.js";
import "../../chunk-NEEIRLS6.js";
import "../../chunk-WZDTE5W3.js";
import "../../chunk-VBSEGKT7.js";
import "../../chunk-Q3QHD23G.js";
import "../../chunk-CYDFP47V.js";
import "../../chunk-URTIMVUU.js";
import "../../chunk-DXM327S3.js";
import "../../chunk-2VA3UGW7.js";
import "../../chunk-5OVSRAPG.js";
import "../../chunk-NLNCD3ES.js";
import "../../chunk-BMLTMNZA.js";
import "../../chunk-7QYVSWCZ.js";
import "../../chunk-VI7IQ5ZG.js";
import "../../chunk-TSCDX4AS.js";
import "../../chunk-AN7WCP7S.js";
import "../../chunk-D6B6MYVG.js";
import "../../chunk-2DAGZ4FT.js";
import "../../chunk-3MLDC2KV.js";
import "../../chunk-7G6NITL4.js";
import "../../chunk-RSLTBO5X.js";
import "../../chunk-I45WP5PM.js";
import "../../chunk-MIZOLME5.js";
import "../../chunk-AKLYUMQO.js";
import "../../chunk-YX6CL4KH.js";
import "../../chunk-ZFRTRIT4.js";
import "../../chunk-CFICINSP.js";
import "../../chunk-3KKFLSLG.js";
import "../../chunk-PLBFBDKH.js";
import "../../chunk-2H4XRKWS.js";
import "../../chunk-WJUQ3VXF.js";
import "../../chunk-O4GTSXBN.js";
import "../../chunk-2OUSR2BE.js";
import "../../chunk-ZDZ4EQHN.js";
import "../../chunk-PZP2B3FC.js";
import "../../chunk-NSJKG6AJ.js";
import "../../chunk-XHPHUZE4.js";
import "../../chunk-NRGUBMFA.js";
import "../../chunk-H564H42Z.js";
import "../../chunk-PE4JT3J7.js";
import "../../chunk-FL5CT6MC.js";
import "../../chunk-2HWPZ6ZE.js";
import "../../chunk-LAWEUL6N.js";
import "../../chunk-V5ZQ2SFQ.js";
import "../../chunk-DGP32WEQ.js";
import "../../chunk-EDNCPFSF.js";
import "../../chunk-73CVRDI7.js";
import "../../chunk-3KQS63H6.js";
import "../../chunk-C7K2ID3C.js";
import "../../chunk-L324TYGN.js";
import "../../chunk-5DS3NT57.js";
import "../../chunk-HLRQ5H3N.js";
import "../../chunk-UO7L7NBK.js";
import "../../chunk-QUQRUDWG.js";
import "../../chunk-ITJJZ6AV.js";
import "../../chunk-QUKKMPRF.js";
import "../../chunk-GY34N3KU.js";
import "../../chunk-X56GIAWQ.js";
import "../../chunk-PN34O4SN.js";
import "../../chunk-UOAPXGA4.js";
import "../../chunk-HJ22ULAI.js";
import {
  Uint8ArrayToHexDump,
  equalBinary,
  toHex
} from "../../chunk-EJGW3W3K.js";
import "../../chunk-EAYWSLQT.js";
import "../../chunk-I7BWSAN6.js";

// src/common/bin/index.spec.ts
describe("encoder", () => {
  it("should write a stream", () => {
    const stream = createBinaryStreamEncoder();
    stream.writeUint32(1);
    stream.write({ a: "99" });
    stream.writeBytes([1, 2, 3], 3);
    stream.write(123);
    const bin = stream.getUint8Array();
    expect(Uint8ArrayToHexDump(bin)).toMatchInlineSnapshot(`
      "0000  01 00 00 00 76 01 01 61 77 02 39 39 01 02 03 7d  ....v..aw.99...}
      0010  bb 01                                            \xBB.              "
    `);
    expect(stream.getLength()).toBe(18);
    const readStream = createBinaryStreamDecoder(bin);
    expect(readStream.getOffset()).toBe(0);
    expect(readStream.readUint32()).toBe(1);
    expect(readStream.getOffset()).toBe(4);
    expect(readStream.read()).toEqual({ a: "99" });
    expect(readStream.readBytes(3)).toMatchInlineSnapshot(`
Uint8Array [
  1,
  2,
  3,
]
`);
    expect(readStream.read()).toBe(123);
    expect(readStream.getOffset()).toBe(bin.length);
  });
  it("should bitfield", () => {
    const bf = bitfield(1);
    bf.setBit(4);
    expect(bf.getValue()).toBe(17);
    bf.setBit(0, false);
    expect(bf.getValue()).toBe(16);
    bf.setBit(1);
    bf.setBit(5);
    bf.setBit(16);
    expect(bf.getValue().toString(2)).toMatchInlineSnapshot(
      '"10000000000110010"'
    );
    expect(bf.getValue()).toBe(65586);
    expect(bf.getBit(0)).toBe(false);
    expect(bf.getBit(4)).toBe(true);
    bf.toggleBit(4);
    expect(bf.getBit(4)).toBe(false);
    expect(bf.getValue()).toBe(65570);
  });
  it("should var bin", () => {
    function enc(v) {
      const e = createBinaryStreamEncoder();
      e.writeIntVar(v);
      return toHex(e.getUint8Array());
    }
    expect(enc(1)).toMatchInlineSnapshot('"01"');
    expect(enc(128)).toMatchInlineSnapshot('"8002"');
    expect(enc(-1)).toMatchInlineSnapshot('"41"');
    expect(enc(-691529286)).toMatchInlineSnapshot('"c699bf9305"');
    expect(enc(691529286)).toMatchInlineSnapshot('"8699bf9305"');
  });
  it("should var bin uint", () => {
    function enc(v) {
      const e = createBinaryStreamEncoder();
      e.writeUintVar(v);
      return toHex(e.getUint8Array());
    }
    expect(enc(1)).toMatchInlineSnapshot('"01"');
    expect(enc(127)).toMatchInlineSnapshot('"7f"');
    expect(enc(128)).toMatchInlineSnapshot(`"8001"`);
    expect(enc(255)).toMatchInlineSnapshot('"ff01"');
    expect(enc(256)).toMatchInlineSnapshot('"8002"');
    expect(enc(691529286)).toMatchInlineSnapshot('"c6ccdfc902"');
  });
  it("should be consistent", () => {
    const bin1 = encodeJson({
      a: 1,
      b: 2
    });
    const bin2 = encodeJson({
      b: 2,
      a: 1
    });
    expect(equalBinary(bin1, bin2)).toBe(true);
  });
});
//# sourceMappingURL=index.spec.js.map