"use strict";

var _chunkXTDX3HZAcjs = require('../chunk-XTDX3HZA.cjs');
require('../chunk-IMCDDJAJ.cjs');

// src/common/timeout.spec.ts
var _vitest = require('vitest');
_vitest.describe.call(void 0, "safeTimeout", () => {
  _vitest.beforeEach.call(void 0, () => {
    _vitest.vi.useFakeTimers();
  });
  _vitest.afterEach.call(void 0, () => {
    _vitest.vi.useRealTimers();
  });
  _vitest.it.call(void 0, "should call the provided function after the specified delay", () => {
    const mockFn = _vitest.vi.fn();
    const delay = 1e3;
    const dispose = _chunkXTDX3HZAcjs.safeTimeout.call(void 0, mockFn, delay);
    _vitest.vi.advanceTimersByTime(delay);
    _vitest.expect.call(void 0, mockFn).toHaveBeenCalledTimes(1);
    dispose();
  });
  _vitest.it.call(void 0, "should allow the timer to be disposed of before it executes", () => {
    const mockFn = _vitest.vi.fn();
    const delay = 1e3;
    const dispose = _chunkXTDX3HZAcjs.safeTimeout.call(void 0, mockFn, delay);
    dispose();
    _vitest.vi.advanceTimersByTime(delay);
    _vitest.expect.call(void 0, mockFn).toHaveBeenCalledTimes(0);
  });
  _vitest.it.call(void 0, "should allow multiple calls to disposeTimer", () => {
    const mockFn = _vitest.vi.fn();
    const delay = 1e3;
    const dispose = _chunkXTDX3HZAcjs.safeTimeout.call(void 0, mockFn, delay);
    dispose();
    dispose();
    _vitest.vi.advanceTimersByTime(delay);
    _vitest.expect.call(void 0, mockFn).toHaveBeenCalledTimes(0);
  });
  _vitest.it.call(void 0, "should work with a zero delay", () => {
    const mockFn = _vitest.vi.fn();
    const dispose = _chunkXTDX3HZAcjs.safeTimeout.call(void 0, mockFn, 0);
    _vitest.vi.advanceTimersByTime(0);
    _vitest.expect.call(void 0, mockFn).toHaveBeenCalledTimes(1);
    dispose();
  });
});
//# sourceMappingURL=timeout.spec.cjs.map